<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */
include dirname(__FILE__) . '/../../../config/config.inc.php';
include dirname(__FILE__) . '/../../../init.php';
require dirname(__FILE__) . '/../vendor/autoload.php';

use ShipQuik\PrestaShop\ShipQuik_BD;
use ShipQuik\Shared\ShipQuik_Helper;

$module_name = 'ship_quik';

$token = pSQL(Tools::encrypt($module_name . '/ajax_repackaging.php'));
$token_url = pSQL(Tools::getValue('token'));

if ($token != $token_url || !Module::isInstalled($module_name)) {
    exit('Error al ejecutar el ajax');
}

$module = Module::getInstanceByName($module_name);
if ($module->active) {
    $order_id = pSQL(Tools::getValue('order_id'));

    $orderResponse = [];
    $orderProductsResponse = [];
    $order = new Order((int) $order_id);

    if ($order) {
        $orderProducts = $order->getProducts();

        $context = Context::getContext();

        foreach ($orderProducts as $orderProduct) {
            $product = new Product($orderProduct['id_product']);

            if ($product) {
                $image = Image::getCover($product->id);
                $link = new Link();
                $imagePath = $link->getImageLink($product->link_rewrite[$context->language->id], $image['id_image']);

                $orderProductsResponse[] = [
                    'sku' => $product->reference,
                    'name' => Product::getProductName($product->id),
                    'quantity' => $orderProduct['product_quantity'],
                    'measures' => (string) round($product->depth, 2) . 'x' . round($product->width, 2) . 'x' . round($product->height, 2),
                    'image' => ($_SERVER['REQUEST_SCHEME'] == 'http' ? 'http://' : 'https://') . $imagePath,
                    'remainder' => $orderProduct['product_quantity'],
                    'measuresraw' => [
                        'width' => round($product->width, 2),
                        'height' => round($product->height, 2),
                        'depth' => round($product->depth, 2),
                        'weight' => round($product->weight, 2),
                    ],
                ];
            }
        }

        $result = ShipQuik_BD::getDatabyOrderId($order_id);
        $supplierInfo = [];
        $shipmentInfo = [];

        if ($result) {
            $supplierInfo = ShipQuik_Helper::mb_unserialize(base64_decode($result['supplier_data']));
            $shipmentInfo = json_decode(str_replace('&quot;', '"', $result['total_payment']), true, 99);
        }

        $packagesInfo = Configuration::get('_SHIP_QUIK_shippingPackageList');

        if (empty($packagesInfo)) {
            $response = ['status' => 200, 'message' => 'Ha habido un problema para solicitar el pedido.'];
        } else {
            $packagesInfo = unserialize($packagesInfo);
        }

        $orderResponse = [
            'order_id' => $order_id,
            'products' => $orderProductsResponse,
            'packages' => $packagesInfo,
            'labels' => [
                ['label' => 'Foto', 'key' => 'image'],
                ['label' => 'Nº', 'key' => 'sku'],
                ['label' => 'Artículo', 'key' => 'name'],
                ['label' => 'Medidas', 'key' => 'measures'],
                ['label' => 'Cant.', 'key' => 'quantity'],
            ],
            'supplierInfo' => $supplierInfo,
            'shipmentInfo' => $shipmentInfo,
            'total_shipping_tax_excl' => $order->total_shipping_tax_excl,
            'total_shipping_tax_incl' => $order->total_shipping_tax_incl,
            'currency_symbol' => $context->currency->sign,
        ];

        $response = ['status' => 200, 'order' => $orderResponse];
    } else {
        $response = ['status' => 200, 'message' => 'Ha habido un problema para solicitar el pedido.'];
    }

    echo json_encode($response);
}
