<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */
class Ship_QuikActionAdminControllerSetMediaController
{
    protected $module;
    protected $file;
    protected $_path;

    protected $context;

    public function __construct($module, $file, $path)
    {
        $this->file = $file;
        $this->module = $module;
        $this->context = Context::getContext();
        $this->_path = $path;
    }

    public function run($params)
    {
        // Only on AdminOrder page
        if ('AdminOrders' === $this->context->controller->php_self) {
            $this->context->controller->addJS($this->_path . 'views/js/repackaging.js', false);
            $this->context->controller->addJS($this->_path . 'views/js/order.js', false);
            $this->context->controller->addCSS($this->_path . 'views/css/admin.css', 'all', false);
            $this->context->controller->addCSS('//fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@48,400,0,0', 'all', false);

            $this->context->controller->addJS($this->_path . 'views/js/jquery-ui.min.js', false);
            $this->context->controller->addCSS($this->_path . 'views/css/jquery-ui.css', 'all', false);
            // $this->context->controller->addJS($this->_path . 'views/js/multidraggable.js', false);

            $shop = new Shop((int) $this->context->shop->id);

            $base_url = $shop->getBaseURL(true);

            // if (Tools::getValue('redirect_status') && Tools::getValue('redirect_status') == 'succeeded') {
            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_send_order.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_send_order.php'));
            Media::addJsDef(['shipquik_order_ajax' => $ajax]);
            // }

            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_order_pickup.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_order_pickup.php'));
            Media::addJsDef(['shipquik_order_pickup_ajax' => $ajax]);

            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_print_label.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_print_label.php'));
            Media::addJsDef(['shipquik_label_ajax' => $ajax]);

            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_repackaging.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_repackaging.php'));
            Media::addJsDef(['shipquik_repackaging_ajax' => $ajax]);

            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_repackaging_totals.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_repackaging_totals.php'));
            Media::addJsDef(['shipquik_repackaging_totals_ajax' => $ajax]);

            $ajax = $base_url . 'modules/' . $this->module->name . '/ajax/ajax_repackaging_save.php?token=' . pSQL(Tools::encrypt($this->module->name . '/ajax_repackaging_save.php'));
            Media::addJsDef(['shipquik_repackaging_save_ajax' => $ajax]);

            if (Tools::getValue('ShipQuikPaymentSelectedOrders')) {
                Media::addJsDef(['shipquik_selected_orders' => Tools::htmlentitiesUTF8(Tools::getValue('ShipQuikPaymentSelectedOrders'))]);
            }
            if (Tools::getValue('paymentKey')) {
                $this->context->controller->addCSS($this->_path . 'views/css/stripe.css', 'all', false);
                $this->context->controller->addJS($this->_path . 'views/js/stripe.js', false);
                $this->context->controller->addJS('https://js.stripe.com/v3/', false);

                Media::addJsDef(['stkey' => $this->module->config->getValueByKey('stkey')]);

                Media::addJsDef(['shipquik_selected_orders' => Tools::htmlentitiesUTF8(Tools::getValue('ordersId'))]);
                Media::addJsDef(['paymentTotal' => Tools::htmlentitiesUTF8(Tools::getValue('paymentTotal'))]);
                Media::addJsDef(['paymentEmail' => Tools::htmlentitiesUTF8(Tools::getValue('paymentEmail'))]);
                Media::addJsDef(['paymentKey' => Tools::htmlentitiesUTF8(Tools::getValue('paymentKey'))]);
                Media::addJsDef(['paymentReturnSubmitUrl' => Tools::htmlentitiesUTF8(Tools::getValue('paymentReturnSubmitUrl'))]);
                Media::addJsDef(['paymentReturnCancelUrl' => Tools::htmlentitiesUTF8(Tools::getValue('paymentReturnCancelUrl'))]);
            }
        } elseif (Tools::getValue('configure') == $this->module->name) {
            $this->context->controller->addJS($this->_path . 'views/js/settings-form.js', false);
            $this->context->controller->addJS($this->_path . 'views/js/settings-tablerates.js', false);
            $this->context->controller->addJS($this->_path . 'views/js/settings-packagelist.js', false);
            $this->context->controller->addCSS($this->_path . 'views/css/settings.css', 'all', false);
        }
    }
}
