<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

use PrestaShop\PrestaShop\Core\Grid\Action\Bulk\Type\SubmitBulkAction;
use ShipQuik\PrestaShop\ShipQuikHtmlTypeColumnAction;
use ShipQuik\PrestaShop\ShipQuikHtmlTypeColumnCost;
use ShipQuik\PrestaShop\ShipQuikHtmlTypeColumnPickup;
use ShipQuik\PrestaShop\ShipQuikHtmlTypeColumnStatus;

class Ship_QuikActionOrderGridDefinitionModifierController
{
    protected $module;
    protected $file;
    protected $_path;

    protected $context;

    public function __construct($module, $file, $path)
    {
        $this->file = $file;
        $this->module = $module;
        $this->context = Context::getContext();
        $this->_path = $path;
    }

    public function run($params)
    {
        if (empty($params['definition'])) {
            return;
        }

        $paymentMethod = $this->module->config->getPaymentMethod();
        $definition = $params['definition'];

        // Columns
        $columns = $definition->getColumns();

        $tempColumn1 = new ShipQuikHtmlTypeColumnPickup('ship_quik_pickup');
        $tempColumn1->setName('Ship-Quik Fecha/Hora Recogida')
            ->setOptions([
                'ModuleClass' => new Ship_Quik(),
                'custom_html' => '<span></span>',
        ]);

        $tempColumn2 = new ShipQuikHtmlTypeColumnCost('ship_quik_cost');
        $tempColumn2->setName('Ship-Quik Coste')
            ->setOptions([
                'ModuleClass' => new Ship_Quik(),
                'custom_html' => '<span></span>',
        ]);

        $tempColumn3 = new ShipQuikHtmlTypeColumnStatus('ship_quik_status');
        $tempColumn3->setName('Ship-Quik Pago')
            ->setOptions([
                'ModuleClass' => new Ship_Quik(),
                'custom_html' => '<span></span>',
        ]);

        $tempColumn4 = new ShipQuikHtmlTypeColumnAction('ship_quik_action');
        $tempColumn4->setName('Ship-Quik Acción')
            ->setOptions([
                'ModuleClass' => new Ship_Quik(),
                'custom_html' => '<span></span>',
        ]);

        $columns->addAfter('payment', $tempColumn4);
        $columns->addAfter('payment', $tempColumn3);
        $columns->addAfter('payment', $tempColumn2);
        $columns->addAfter('payment', $tempColumn1);

        $definition->setColumns($columns);

        $bulkActions = $definition->getBulkActions();

        if ($paymentMethod == 1) {
            // Bulk Actions Stripe
            $bulkAction = new SubmitBulkAction('shipquik_modal_form_stripe');
            $bulkAction->setName($this->module->l('Pagar pedidos Ship-Quik'))
            ->setOptions(
                ['submit_route' => 'shipquik_modal_form_stripe']);
            $bulkActions->add($bulkAction);
        } else {
            // Bulk Actions No Stripe
            $bulkAction = new SubmitBulkAction('shipquik_bulk_order_shipment');
            $bulkAction->setName($this->module->l('Realizar pedidos Ship-Quik'))
            ->setOptions(
                ['submit_route' => 'shipquik_bulk_order_shipment']
            );
            $bulkActions->add($bulkAction);

            // Bulk Actions Check Orders
            // $bulkAction2 = new SubmitBulkAction('shipquik_bulk_order_check_payment');
            // $bulkAction2->setName($this->module->l('Comprobar pagos Ship-Quik'))
            // ->setOptions(
            //     array('submit_route' => 'shipquik_bulk_order_shipment')
            // );
            // $bulkActions->add($bulkAction2);
        }

        $definition->setBulkActions($bulkActions);
    }
}
