<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

use ShipQuik\PrestaShop\ShipQuik_ShippingPackage;
use ShipQuik\PrestaShop\ShipQuik_ShippingRate;
use ShipQuik\Shared\ShipQuik_PricingMode;
use ShipQuik\Shared\ShipQuik_Suppliers;

class Ship_QuikGetOrderShippingCostController
{
    protected $module;
    protected $file;
    protected $_path;

    protected $context;

    public function __construct($module, $file, $path)
    {
        $this->file = $file;
        $this->module = $module;
        $this->context = Context::getContext();
        $this->_path = $path;
    }

    public function getShipQuikDeliveryService($cart, $id_carrier)
    {
        $packages = [];
        $packages['destination'] = new Address($cart->id_address_delivery);
        $packages['contents'] = $cart->getProducts(true);

        $result = [];

        $shippingPackage = new ShipQuik_ShippingPackage($this->module, $packages['contents'], 'kg');
        $boxes = $shippingPackage->getBoxes($this->module->config, $packages['contents']);

        if (isset($packages['destination']->postcode) && $packages['destination']->postcode) {
            // $cache_key = md5($this->module->name.'.suppliers.' . serialize($boxes));

            // if ($result = Cache::getInstance()->get($cache_key)) {
            //     return json_decode($result, true);
            // }

            $shipQuikSuppliers = new ShipQuik_Suppliers($this->module, $boxes, $packages['destination'], $id_carrier);
            $result = ShipQuik_PricingMode::create($this->module, $this->module->config->getValueByKey('pricingMode'))->getForRates($shipQuikSuppliers);

            // Cache::getInstance()->set($cache_key, json_encode($result));
            // $pepe = Cache::isStored($cache_key);
        }

        return ['pricingMode' => $result, 'shippingPackage' => $packages];
    }

    public function getShipQuikShippingCost($parent, $pricingMode, $rate, $cart)
    {
        $shipping_cost = false;

        if ($pricingMode) {
            $ShippingRate = new ShipQuik_ShippingRate($parent, $rate, $cart);
            $shipping_cost = $ShippingRate->getRate($cart, $pricingMode['pricingMode'], $pricingMode['shippingPackage']);
        }

        return $shipping_cost;
    }

    public function run($cart, $shipping_fees)
    {
        $shipping_cost = false;

        $pricingMode = $this->getShipQuikDeliveryService($cart, $this->module->id_carrier);

        if ($this->module->id_carrier == Configuration::get('_SHIP_QUIK_PRICE')) {
            $shipping_cost = $this->getShipQuikShippingCost($this->module, $pricingMode, 'price', $cart);
        }
        if ($this->module->id_carrier == Configuration::get('_SHIP_QUIK_SPEED')) {
            $shipping_cost = $this->getShipQuikShippingCost($this->module, $pricingMode, 'speed', $cart);
        }
        if ($shipping_cost === false) {
            return false;
        }

        return $shipping_cost; // $shipping_fees;
    }
}
