<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace ShipQuik\Shared;

class ShipQuik_Configuration
{
    private static $_instance = null;

    protected $parent = null;

    public $base = '';

    public function __construct($parent = null)
    {
        $this->parent = $parent;

        $this->base = '_' . $this->parent->_token . '_';
    }

    public function getConfig()
    {
        return json_decode(\Tools::file_get_contents(CONFIG_DATA), true);
    }

    public static function get_option($key)
    {
        return \Configuration::get($key);
    }

    public static function update_option($key, $value)
    {
        return \Configuration::updateValue($key, $value);
    }

    public function getPaymentMethod()
    {
        try {
            $data = unserialize(self::get_option($this->base . 'activation'));

            return isset($data->paymentMethod) ? (int) $data->paymentMethod : 1;
        } catch (\Exception $e) {
            return null;
        }
    }

    public function getClientType()
    {
        try {
            $data = self::get_option($this->base . 'activation');

            return isset($data->clientType) ? (int) $data->clientType : 0;
        } catch (\Exception $e) {
            return null;
        }
    }

    public function getIdCliente()
    {
        try {
            $token = $this->getAccessToken();

            if (!$token) {
                return null;
            }

            $tokenDecoded = $this->getTokenDecoded($token);

            return $tokenDecoded->id;
        } catch (\Exception $e) {
            return null;
        }
    }

    public function getTokenDecoded($token)
    {
        $decoded = json_decode(base64_decode(str_replace('_', '/', str_replace('-', '+', explode('.', $token)[1]))));

        return $decoded;
    }

    public function reNewAccessToken()
    {
        $auth = new ShipQuik_Auth($this->parent);
        $auth->send();
    }

    public function getAccessToken()
    {
        $auth = unserialize(self::get_option($this->base . 'activation'));

        return $auth ? $auth->token : null;
    }

    public function setAccessToken($token)
    {
        self::update_option($this->base . 'activation', serialize($token));
    }

    public function getValueByKey($myKey = '')
    {
        foreach ($this->getConfig() as $key => $value) {
            if ($key == $myKey) {
                return $value;
            }
        }

        $value = self::get_option($this->base . $myKey);

        if ($value == 'yes' || $value == 'no') {
            return $value == 'yes' ? true : false;
        }

        return $value;
    }

    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }

        return self::$_instance;
    } // End instance()

    public function __clone()
    {
        trigger_error('La clonación de este objeto no está permitida', E_USER_ERROR);
    }
}
