<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace ShipQuik\Shared;

use ShipQuik\PrestaShop\ShipQuik_Shipments;

class ShipQuik_ShippingDua
{
    private static $_instance = null;

    protected $parent;

    protected $boxes;

    protected $destination;

    protected $supplier;

    protected $declaredValue;

    protected $config;

    protected $data;

    public function __construct($parent = null, $boxes = [], $destination = [], $supplier = '', $declaredValue = 0)
    {
        $this->parent = $parent;
        $this->boxes = $boxes;
        $this->destination = $destination;
        $this->supplier = $supplier;
        $this->declaredValue = $declaredValue;

        $this->config = $parent->config;

        $this->data = $this->getData($this->boxes, $this->destination, $this->supplier, $this->declaredValue);
    }

    private function getData($boxes, $destination, $supplier = '', $declaredValue = 0)
    {
        $supplierData = [];

        $customerAddress = $destination;

        $senderAddress = ShipQuik_Shipments::getSenderAddress($this->config);

        $supplierData['postalCodeOrigin'] = $senderAddress['PostalCode'];
        $supplierData['postalCodeDestination'] = $customerAddress['postcode'];
        $supplierData['countryCodeOrigin'] = $senderAddress['CountryCode'];
        $supplierData['countryCodeDestination'] = $customerAddress['countrycode'];
        $supplierData['cityOrigin'] = $senderAddress['City'];
        $supplierData['cityDestination'] = $customerAddress['city'];
        // $supplierData['addressDescOrigin']      = $senderAddress['Street'];
        // $supplierData['addressDescDestination'] = $customerAddress['street'];

        $supplierData['pesoEnKG'] = true;

        $supplierData['boxes'] = $boxes;

        $supplierData['supplier'] = $supplier;
        $supplierData['declaredValue'] = $declaredValue;

        return $supplierData;
    }

    public function send()
    {
        $result = false;

        $params = [];

        $params['Baseurl'] = $this->config->getValueByKey('endpoints')['getDua'];
        $params['Data'] = $this->data;

        // d(json_encode($params['Data']));

        $curl = new ShipQuik_API($this->parent, $params, true);
        $result = $curl->runCall();

        if ($result == 'renew_token') {
            $this->config->reNewAccessToken();

            $result = $curl->runCall();
        }

        if ($result) {
            if (isset($result['data'])) {
                return $result;
            }
        }

        return $result;
    }

    public static function instance()
    {
        if (!isset(self::$_instance)) {
            $class = __CLASS__;
            self::$_instance = new $class();
        }

        return self::$_instance;
    }

    public function __clone()
    {
        trigger_error('La clonación de este objeto no está permitida', E_USER_ERROR);
    }
}
