/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */
document.addEventListener('DOMContentLoaded', function () {
    jQuery('.ship-quik-print-label').on('click', function(event) {
        printLabel(jQuery(this).data('key'), this);
    });

    function printLabel(order_id, parent) {
        jQuery('#labelsShipQuikOrdersModal .modal-body').html('');
        jQuery.ajax({
            type: "POST",
            url: shipquik_label_ajax,
            data: {'order_id' : order_id },
            cache: false,
            dataType: "json",
            success: function(response) {
                jQuery.each(response.labels, function() {
                    if (response.labelsMimeType == 'image/png') {
                        jQuery('#labelsShipQuikOrdersModal .modal-body').append('<img style="display: block; width: 100%; height: 600px" src="data:image/png;base64, ' + this + '#toolbar=1&navpanes=0&scrollbar=0" />');
                    } else {
                        jQuery('#labelsShipQuikOrdersModal .modal-body').append('<embed style="display: block; width: 100%; height: 600px;" src="data:application/pdf;base64, ' + this + '#toolbar=0&navpanes=0&scrollbar=0" type="' + response.labelsMimeType + '" />');
                    }
                    jQuery(parent).addClass('ship-quik-reprint-label');
                    jQuery(parent).html('update');
                });
                jQuery('#labelsShipQuikOrdersModal').modal('show');
                jQuery('#labelsShipQuikOrdersModal').modal('handleUpdate');
            }
        });
    }

    function send_order(order_id, parent)
    {
        jQuery(".shipquik_loader_" + order_id).show();

        jQuery.ajax({
            type: "POST",
            url: shipquik_order_ajax,
            data: {'order_id' : order_id },
            cache: false,
            dataType: 'json',
            success: function (response) {
                if (response.status == 200 && response.hasOwnProperty('reference')) {
                    jQuery(parent).parent().html(
                        '<span title="Etiqueta pendiente" class="material-symbols-outlined ship-quik-print-label" data-key="' + order_id + '">print</span>'
                    );
                    jQuery('.ship-quik-print-label').on('click', function(event) {
                        printLabel(jQuery(this).data('key'));
                    });
                } else {
                    jQuery(parent).parent().html('<p style="color: red;">' + response.message + '</p>');
                    console.log(response);
                }
                jQuery(".shipquik_loader_" + order_id).hide();
            },
            error: function (XMLHttpRequest, textStatus, errorThrown) {
                console.log(textStatus);
                jQuery(".shipquik_loader").hide();
            }
        });
    }

    jQuery('.ship-quik-send-order').on('click', function () {
        send_order(jQuery(this).attr('data-key'), this);
    });

    jQuery('.ship-quik-pickdate').on('input', function () {
        var parent = this;
        jQuery.ajax({
            type: "POST",
            url: shipquik_order_pickup_ajax,
            data: {
                'order_id'    : jQuery(parent).attr('data-key'),
                'pickup_date' : jQuery(parent).val(),
                'pickup_time' : jQuery(parent).prev().val()
            },
            cache: false,
            dataType: "json",
            success: function(response) {
                if (response.status == 200 && response.hasOwnProperty('error')) {
                    alert(response.error);
                } else {
                    jQuery(parent).removeClass('ship-quik-pickdate-red');
                    if (jQuery(parent).val() != response.date) {
                        var today  = new Date(response.date);
                        alert("La fecha seleccionada no esta disponible, se asignará el día " + today.toLocaleDateString("es-ES"));
                        jQuery(parent).val(response.date);
                    }
                }
            }
        });
    });

    jQuery('.ship-quik-picktime').on('change', function () {
        var parent = this;
        jQuery.ajax({
            type: "POST",
            url: shipquik_order_pickup_ajax,
            data: {
                'order_id'    : jQuery(parent).attr('data-key'),
                'pickup_date' : jQuery(parent).next().val(),
                'pickup_time' : jQuery(parent).val()
            },
            cache: false,
            dataType: "json",
            success: function(response) {
                if (response.status == 200 && response.hasOwnProperty('error')) {
                    alert("Introduzca una fecha correcta.");
                } else {
                    jQuery(parent).removeClass('ship-quik-picktime-red');
                }
            }
        });
    });
});
