/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author Ship-Quik SL <info@ship-quik.com>
 * @copyright Since 2022 Ship-Quik SL
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */
document.addEventListener('DOMContentLoaded', function () {
    // # Globals
    var shipQuikOrder = {};

    function create_UUID() {
        var dt = new Date().getTime();
        var uuid = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
            var r = (dt + Math.random()*16)%16 | 0;
            dt = Math.floor(dt/16);
            return (c=='x' ? r :(r&0x3|0x8)).toString(16);
        });
        return uuid;
    }

    // # Events definition

    // Event for repackaging button
    jQuery('.ship-quik-repackaging').on('click', function(event) {
        shipQuikOrder = {};
        repackagingStart(jQuery(this).data('key'), this);
    });

    // #Starting app
    function repackagingStart(order_id, parent) {
        jQuery('#repackagingShipQuikOrderModal .modal-body').html('');
        jQuery('#repackagingShipQuikOrderModal .modal-footer').html('');

        jQuery.ajax({
            type: "POST",
            url: shipquik_repackaging_ajax,
            data: {'order_id' : order_id},
            cache: false,
            dataType: "json",
            success: function(response) {
                if (response.status == 200 && response.hasOwnProperty('order')) {
                    shipQuikOrder = response.order;

                    renderBody(jQuery('#repackagingShipQuikOrderModal .modal-body'), response.order);
                    renderFooter(jQuery('#repackagingShipQuikOrderModal .modal-footer'), response.order);

                    addProductsListHandlers();
                    addPackagesListHandlers();
                    addTotalsHandler();
                    addSaveHandler();

                    jQuery('#repackagingShipQuikOrderModal').modal('show');
                }
            }
        });
    }

    // Event for products click
    function addProductsListHandlers() {
        var rows = document.getElementsByClassName("product");
        for (i = 0; i < rows.length; i++) {
            jQuery(rows[i]).draggable({ revert: true });
        }
    }

    // Event for packages click
    function addPackagesListHandlers() {
        jQuery("#repackagingShipQuikOrderModal select").select();

        jQuery('#repackagingShipQuikOrderModal .package-create').on('click', function(event) {
            var dataPackage = jQuery('#repackagingShipQuikOrderModal #ship-quik-package-select').find(':selected').data('package');
            var PackageObj = JSON.parse(decodeURIComponent(dataPackage));

            addPackage(PackageObj);
        });
    }

    function addPackageProductHandler(packageProductUID, productUID) {
        jQuery('#repackagingShipQuikOrderModal .packageproduct-delete-' + packageProductUID).on('click', function(event) {
            var result = confirm("¿Estas seguro que deseas eliminar este producto?");
            if (result) {
                var productRemainder = jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').data('remainder');
                var packageProductQuantity = jQuery('.ship-quik-repackaging-packageproductlist [data-uid="' + packageProductUID +  '"] ').data('quantity');
                var diff = productRemainder + packageProductQuantity;
                if (diff < 1) diff = 1;
                jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').data('remainder', diff);
                jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').find('.product-quantity').html('<b>' + (diff) + '</b>');
                jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').removeClass('product-selected');

                var parentList = jQuery('.ship-quik-repackaging-packageproductlist [data-uid="' + packageProductUID +  '"] ').parent();
                jQuery(this).parent().remove();

                if (jQuery(parentList).children().length == 0) {
                    jQuery(parentList).parent().find('.drop-text').show();
                    jQuery(parentList).parent().removeClass('container-droppable-withdata').addClass('container-droppable');
                }
            }
        });
    }

    function addTotalsHandler() {
        jQuery('#repackagingShipQuikOrderModal .recalc-totals').on('click', function(event) {
            var data = getData();

            if (data.length > 0) {
                jQuery.ajax({
                    type: "POST",
                    url: shipquik_repackaging_totals_ajax,
                    data: {
                        'order_id' : shipQuikOrder.order_id,
                        'data' : data
                    },
                    cache: false,
                    dataType: "json",
                    success: function(response) {
                        if (response.status == 200 && response.hasOwnProperty('totals')) {
                            shipQuikOrder = response.totals;
                            jQuery('#repackagingShipQuikOrderModal .newtotal span').html(shipQuikOrder.payment.total);
                        }
                    }
                });
            }
        });
    }

    function addSaveHandler() {
        jQuery('#repackagingShipQuikOrderModal .shipquik-repackaging-save').on('click', function(event) {

            var data = getData();

            if (data.length > 0) {
                jQuery.ajax({
                    type: "POST",
                    url: shipquik_repackaging_save_ajax,
                    data: {
                        'order_id' : shipQuikOrder.order_id,
                        'data' : data
                    },
                    cache: false,
                    dataType: "json",
                    success: function(response) {
                        if (response.status == 200 && response.hasOwnProperty('save')) {
                            jQuery('.shipquik-price-' + shipQuikOrder.order_id).html(response.save.payment.total);
                            jQuery('#repackagingShipQuikOrderModal').modal('hide');
                        } else {
                            alert('Hay problema en procesar los datos.');
                        }
                    }
                });
            }
        });
        jQuery('#repackagingShipQuikOrderModal .shipquik-repackaging-cancel').on('click', function(event) {
            var result = window.confirm("¿Estas seguro que quieres cancelar?");
            if (result) {
                jQuery('#repackagingShipQuikOrderModal').modal('hide');
            }
        });
    }

    // Rendering elements
    function renderBody(body, order) {
        var html = '<div class="container-fluid p-0 mb-2">';
            html += '<div class="row">';
                html += '<div class="col-sm-12 col-md-6">';
                    html += '<h3>Pedido:' + order.order_id  + '</h3>';
                html += '</div>';
                html += '<div class="col-sm-12 col-md-6">';
                    html += '<div class="container-fluid p-0">';
                        html += '<div class="row">';
                            html += '<div class="col-10">';
                                html += '<div class="package-product-select">';
                                    html += '<select class="custom-select" id="ship-quik-package-select" class="">';
                                    Object.keys(order.packages).forEach(key => {
                                        var uid = create_UUID();
                                        var package = order.packages[key];
                                        package.uid = uid;
                                        var measures = package.depth + 'x' + package.width + 'x' + package.height;
                                        html += '<option data-package="' + encodeURIComponent(JSON.stringify(package)) + '" value="' + uid + '">' + package.name + ' - ' + measures + '</option>';
                                    });
                                    html += '</select>';
                                html += '</div>';
                            html += '</div>';
                            html += '<div class="col-2">';
                                html += '<i class="material-icons package-create">add</i>';
                            html += '</div>';
                        html += '</div>';
                    html += '</div>';
                html += '</div>';
            html += '</div>';
        html += '</div>';
        html += '<div class="container-fluid p-0">';
            html += '<div class="row">';
                html += '<div class="col-6">';
                    html += '<h4>ORIGINAL</h4>';
                    html += renderProductList(order.products, order.labels);
                html += '</div>';
                html += '<div class="col-6">';
                    html += '<h4>REEMPAQUETAR</h4>';
                    html += renderPackagesList(order.packages);
                html += '</div>';
            html += '</div>';
        html += '</div>';
        jQuery(body).html(html);
    }

    function renderProductList(products, labels) {
        var html = '';
        html += '<div class="container-fluid ship-quik-repackaging-productlist">';
            html += '<div class="row justify-content-md-center header">';
                Object.keys(labels).forEach(key => {
                    if (labels[key].key == 'image') {
                        html += '<div class="col-sm-12 col-md-2 product-' + labels[key].key +  '">' + labels[key].label + '</div>';
                    } else if (labels[key].key == 'name') {
                        html += '<div class="col-sm-12 col-md-4 product-' + labels[key].key + '">' + labels[key].label + '</div>';
                    } else if (labels[key] == 'quantity') {
                        html += '<div class="col-sm-12 col-md-1 product-' + labels[key].key + '">' + labels[key].label + '</div>';
                    } else {
                        html += '<div class="col-sm-12 col-md-2 product-' + labels[key].key + '">' + labels[key].label + '</div>';
                    }
                });
            html += '</div>';
            Object.keys(products).forEach(key => {
                var productkey = key;
                html += '<div class="row draggable product" data-uid="' + create_UUID()
                    + '" data-remainder="' + products[productkey].remainder
                    + '" data-quantity="' + products[productkey].quantity
                    + '" data-weight="' + products[productkey].weight
                    + '" data-product="' + encodeURIComponent(JSON.stringify(products[key])) + '">';
                    Object.keys(labels).forEach(key => {
                        html += renderProduct(labels[key].key, products[productkey][labels[key].key]);
                    });
                html += '</div>';
            });
        html += '</div>';

        return html;
    }

    function renderPackageProduct(product, productuid, labels, userQuantity) {
        nextIndex = create_UUID();
        html = '<div class="row product draggable" data-uid="' + nextIndex
            + '" data-productuid="' + productuid
            + '" data-quantity="' + userQuantity
            + '" data-weight="' + product.measuresraw.weight
            + '" data-product="' + encodeURIComponent(JSON.stringify(product)) + '">';
            Object.keys(labels).forEach(key => {
                html += renderProduct(labels[key].key, product[labels[key].key], 4, userQuantity);
            });
            html += '<div class="col-sm-12 col-md-1 material-icons packageproduct-delete packageproduct-delete-' + nextIndex + '">delete</div>';
        html += '</div>';

        return { 'html': html, 'packageProductUID' : nextIndex };
    }

    function renderProduct(label, value, colspan = 4, userQuantity = 0) {
        var html = '';
        if (label == 'image') {
            html += '<div class="col-sm-12 col-md-2 product-' + label +  '"><img src="' + value + '"/></div>';
        } else if (label == 'name') {
            html += '<div class="col-sm-12 col-md-' + colspan + ' product-' + label + '">' + value + '</div>';
        } else if (label == 'quantity' && userQuantity > 0) {
            html += '<div class="col-sm-12 col-md-1 text-right product-' + label + '">' + userQuantity + '</div>';
        } else {
            html += '<div class="col-sm-12 col-md-2 product-' + label + '">' + value + '</div>';
        }

        return html;
    }

    function renderPackagesList(packages) {
        var html = '';
        html += '<div class="packagelist">';
        html += '</div>';

        return html;
    }

    function renderFooter(footer, order) {
        var html = '<div class="container-fluid">';
            html += '<div class="row">';
                html += '<div class="col-md-6 col-sm-6">';
                    html += renderProductListTotals(order);
                html += '</div>';
                html += '<div class="col-md-6 col-sm-6 offset-md-6">';
                html += '</div>';
            html += '</div>';
            html += '<div class="row">';
                html += '<div class="col-6 mt-4">';
                    html += '<a target="#" class="shipquik-repackaging-cancel btn btn-danger" data-key="' + order.order_id + '">Cancelar</a>';
                html += '</div>';
                html += '<div class="col-6 mt-4">';
                    html += '<a target="#" class="shipquik-repackaging-save btn btn-primary" data-key="' + order.order_id + '">Guardar</a>';
                html += '</div>';
            html += '</div>';
        html += '</div>';

        jQuery(footer).html(html);
    }

// <i class="material-icons recalc-totals">cached</i>

    function renderProductListTotals(order) {
        var totals = getTotals(order.shipmentInfo);
        var html = '';
        html += '<div class="totals container-fluid">';
            html += '<div class="row align-items-start">';
                html += '<div class="col-4 text-center">';
                    html += '<h4>Cobrado cliente</h4>';
                    html += '<h2 class="price">' + (Math.round((order.total_shipping_tax_excl) * 100) / 100) + order.currency_symbol + '</h2>';
                html += '</div>';
                html += '<div class="col-4 text-center">';
                    html += '<h4>Coste actual</h4>';
                    html += '<h2 class="price">' + (Math.round((totals.total) * 100) / 100) + order.currency_symbol + '</h2>';
                html += '</div>';
                html += '<div class="col-4 text-center">';
                    html += '<h4>Nuevo coste</h4>';
                    html += '<h2 class="newtotal price"><span>0</span>' + order.currency_symbol + '</h2>';
                html += '</div>';
            html += '</div>';
            html += '<div class="row align-items-end">';
                html += '<div class="col-8 offset-md-8">';
                html += '</div>';
                html += '<div class="col-4 text-center">';
                    html += '<a target="#" class="recalc-totals btn btn-primary" data-key="' + order.order_id + '">Recalcular</a>';
                html += '</div>';
            html += '</div>';
            html += '</div>';

        return html;
    }

    function getTotals(shipmentInfo) {
        var totals = {};

        totals.base = shipmentInfo.payment.sale;
        totals.total = shipmentInfo.payment.total;
        totals.insurance = 0;

        totals.dua = shipmentInfo.supplier.dua;

        totals.iva = totals.base - totals.total;

        return totals;
    }

    // # Objects management
    function addPackage(PackageObj) {
        var packageUUID = create_UUID();

        var html = '<div class="package package-' + packageUUID + '" data-uid="' + packageUUID  + '" '
                + ' data-depth="' + PackageObj.depth + '"'
                + ' data-width="' + PackageObj.width + '"'
                + ' data-height="' + PackageObj.height + '"'
                + ' data-weight="' + PackageObj.weight + '">';
            html += '<div class="package-delete">';
                html += '<div class="package-name">' + PackageObj.name  + '</div>';
                html += '<i class="package-delete-' + packageUUID + ' material-icons">close</i>';
            html += '</div>';
            html += '<div class="droppable container-droppable">';
                html += '<span class="drop-text">Arrastre los productos aquí</span>';
                html += '<div class="container-fluid ship-quik-repackaging-packageproductlist"></div>';
            html += '</div>';
        html += '</div>';

        jQuery('#repackagingShipQuikOrderModal .packagelist').append(html);

        jQuery('#repackagingShipQuikOrderModal .package-delete-' + packageUUID).on('click', function(event) {
            var result = confirm("¿Estas seguro que deseas eliminar este paquete?");
            if (result) {
                var packageProductList = jQuery(this).parent().parent().find('.ship-quik-repackaging-packageproductlist').children();

                // palido
                jQuery(packageProductList).each(function( index ) {
                    var productUID = jQuery(this).data('productuid');
                    var packageProductUID = jQuery(this).data('uid');

                    var productRemainder = jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').data('remainder');
                    var packageProductQuantity = jQuery('.ship-quik-repackaging-packageproductlist [data-uid="' + packageProductUID +  '"] ').data('quantity');
                    var diff = productRemainder + packageProductQuantity;

                    if (diff < 1) diff = 1;
                    jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').data('remainder', diff);
                    jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').find('.product-quantity').html('<b>' + (diff) + '</b>');
                    jQuery('.ship-quik-repackaging-productlist [data-uid="' + productUID +  '"] ').removeClass('product-selected');
                });

                jQuery(this).parent().parent().remove();
            }
        });

        jQuery('.droppable').droppable({
            hoverClass: 'ship-quik-highlight',
            drop: function(event, product) {
                var productData = JSON.parse(decodeURIComponent(jQuery(product.draggable).data('product')));
                var productUID = jQuery(product.draggable).data('uid');
                var packageProductList = jQuery(this).find('.ship-quik-repackaging-packageproductlist');
                var productRemainder = jQuery(product.draggable).data('remainder');
                var productQuantity = jQuery(product.draggable).data('quantity');

                if (!jQuery(product.draggable).hasClass('product-selected')) {
                    var userQuantity = productQuantity;

                    if (productRemainder > 1) {
                        do {
                            var result = window.prompt("Especifica que cantidad quieres empaquetar", productRemainder);
                            if (result == null) {
                                userQuantity = 0;
                                break;
                            }
                            userQuantity = parseInt(result);
                        } while (isNaN(userQuantity) || userQuantity > productRemainder || userQuantity < 1);
                    }

                    if (userQuantity > 0) {
                        var packageProduct = renderPackageProduct(productData, productUID, shipQuikOrder.labels, userQuantity);

                        jQuery(this)
                            .find('.ship-quik-repackaging-packageproductlist')
                            .append(packageProduct.html);

                        var diff =  productRemainder - userQuantity;

                        jQuery(product.draggable).data('remainder', diff);

                        addPackageProductHandler(packageProduct.packageProductUID, productUID);

                        if (diff == 0) {
                            jQuery(product.draggable).addClass('product-selected');
                        } else {
                            jQuery(product.draggable).find('.product-quantity').html('<b>' + diff + '</b>');
                        }
                    }
                }

                if (jQuery(packageProductList).is(':empty')) {
                    jQuery(this).removeClass('container-droppable-withdata').addClass('container-droppable');
                } else {
                    jQuery(this).removeClass('container-droppable').addClass('container-droppable-withdata');
                    jQuery(this).find('.drop-text').hide();
                }
            }
        });
    }

    function getData() {
        var boxes = [];

        jQuery('.packagelist').each(function( index ) {
            jQuery(this).find('.package').each(function( index ) {
                console.log('package depth: ' + jQuery(this).data('depth'));
                console.log('package width: ' + jQuery(this).data('width'));
                console.log('package height: ' + jQuery(this).data('height'));
                console.log('package weight: ' + jQuery(this).data('weight'));

                var box = {
                    "length": jQuery(this).data('depth'),
                    "width": jQuery(this).data('width'),
                    "height": jQuery(this).data('height'),
                    "weight": jQuery(this).data('weight')
                };

                var totalProductsWeight = 0;

                jQuery(this).find('.product').each(function( index ) {
                    console.log('package weigth: ' + jQuery(this).data('weight'));

                    totalProductsWeight = totalProductsWeight + jQuery(this).data('weight');
                });

                if (totalProductsWeight > jQuery(this).data('weight')) {
                    box.weight = totalProductsWeight;
                }
                boxes.push(box);
            });
        });

        return boxes;
    }
});
